Intro - madmpy

# Welcome to madmpy

madmpy is a Python library for creating, validating, and managing Data Management Plans (DMPs) following the recommendation of the RDA-DMP Common Standard Working Group .

DMPs are commonly used in research institutions, data management workflows, and academic projects to facilitate the structured documentation of datasets, compliance with funding requirements, and integration with research data repositories. The library is derived from the RDA-DMP Common Standard specification, providing a structured approach to defining DMPs.

## Getting Started

To begin using `madmpy`, check out the Installation guide to see how to create and validate your first DMP.

- Ready to code? → Quickstart
- Found a bug? → Contact??
- Read the source? → Github

Next »